@@ -9,8 +9,8 @@
 #
 package MooseX::RelatedClasses;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.009-2-gfc98462
-$MooseX::RelatedClasses::VERSION = '0.010';
+# git description: 0.010-9-gcb11396
+$MooseX::RelatedClasses::VERSION = '0.011';
 
 # ABSTRACT: Parameterized role for related class attributes
 
@@ -31,41 +31,68 @@ use Class::Load 'load_class';
 use String::RewritePrefix;
 
 use Moose::Exporter;
-Moose::Exporter->setup_import_methods(
-    with_meta => [ qw{
-        related_classes   related_class
-        related_namespace
-    } ],
-);
 
 
-sub related_class { goto \&related_classes }
+{
+    package MooseX::RelatedClasses::Exports;
+our $AUTHORITY = 'cpan:RSRCHBOY';
+# git description: 0.010-9-gcb11396
+$MooseX::RelatedClasses::Exports::VERSION = '0.011';
 
-sub related_classes {
-    my $meta = shift;
+    # This is a little awkward, but it resolves the unpleasantness of having
+    # these functions become part of the role (!!!)
+    #
+    # Here we simply create a "dummy" package using Moose exporter, then pull
+    # its imports in via an "also" in the main package.  This resolves things
+    # nicely without having to do any meta-tinkering.
+    #
+    # Sadly.
 
-    if (@_ % 2 == 1) {
-        unshift @_, ref $_[0] ? 'names' : 'name';
-    }
+    use strict;
+    use warnings;
 
-    find_meta('MooseX::RelatedClasses')->apply($meta, @_);
-}
+    use MooseX::Util 'find_meta';
+    use Moose::Exporter;
 
-
-sub related_namespace {
-    my ($meta, $namespace) = (shift, shift);
-
-    my %args = (
-        all_in_namespace => 1,
-        namespace        => $namespace,
-        name             => $namespace,
-        @_,
+    Moose::Exporter->setup_import_methods(
+        with_meta => [ qw{
+            related_class
+            related_classes
+            related_namespace
+        } ],
     );
 
-    ### %args
-    find_meta('MooseX::RelatedClasses')->apply($meta, %args);
+    sub related_class { goto \&related_classes }
+
+    sub related_classes {
+        my $meta = shift;
+
+        if (@_ % 2 == 1) {
+            unshift @_, ref $_[0] ? 'names' : 'name';
+        }
+
+        find_meta('MooseX::RelatedClasses')->apply($meta, @_);
+    }
+
+    sub related_namespace {
+        my ($meta, $namespace) = (shift, shift);
+
+        my %args = (
+            all_in_namespace => 1,
+            namespace        => $namespace,
+            name             => $namespace,
+            @_,
+        );
+
+        ### %args
+        find_meta('MooseX::RelatedClasses')->apply($meta, %args);
+    }
 }
 
+Moose::Exporter->setup_import_methods(
+    also => 'MooseX::RelatedClasses::Exports',
+);
+
 
 parameter name  => (
     traits    => [Shortcuts],
@@ -136,72 +163,66 @@ role {
         $p->_set_names(\%mod);
     }
 
-    $p->names->each(sub { _generate_one_attribute_set($p, @_, %opts) });
-    #_generate_one_attribute_set($p, $_, %opts)
-        #for $p->names->flatten;
+    for my $name ($p->names->keys->flatten) {
+        my $identifier = $p->names->{$name};
+
+        my $full_name
+            = $p->namespace
+            ? $p->namespace . '::' . $name
+            : $name
+            ;
+
+        my $pvt = $p->private ? '_' : q{};
+
+        # SomeThing::More -> some_thing__more
+        my $local_name           = "${identifier}_class";
+        my $original_local_name  = "original_$local_name";
+        my $original_reader      = "$pvt$original_local_name";
+        my $traitsfor_local_name = $local_name . '_traits';
+        my $traitsfor_reader     = "$pvt$traitsfor_local_name";
+
+        ### $full_name
+        has "$pvt$original_local_name" => (
+            traits     => [Shortcuts],
+            is         => 'lazy',
+            isa        => LoadableClass,
+            constraint => sub { $_->isa($full_name) },
+            coerce     => 1,
+            init_arg   => "$pvt$local_name",
+            builder    => sub { $full_name },
+        );
+
+        has "$pvt$local_name" => (
+            traits     => [Shortcuts],
+            is         => 'lazy',
+            isa        => LoadableClass,
+            constraint => sub { $_->isa($full_name) },
+            coerce     => 1,
+            init_arg   => undef,
+            builder    => sub {
+                my $self = shift @_;
+
+                return with_traits( $self->$original_reader() =>
+                    $self->$traitsfor_reader()->flatten,
+                );
+            },
+        );
+
+        # XXX do the same original/local init_arg swizzle here too?
+        has "$pvt$traitsfor_local_name" => (
+            traits  => [Shortcuts, 'Array'],
+            is      => 'lazy',
+            isa     => ArrayRef[LoadableRole],
+            builder => sub { [ ] },
+            handles => {
+                "${pvt}has_$traitsfor_local_name" => 'count',
+            },
+        );
+    }
 
     return;
 };
 
-sub _generate_one_attribute_set {
-    my ($p, $name => $identifier, %opts) = @_;
-
-    my $full_name
-        = $p->namespace
-        ? $p->namespace . '::' . $name
-        : $name
-        ;
-
-    my $pvt = $p->private ? '_' : q{};
-
-    # SomeThing::More -> some_thing__more
-    my $local_name           = "${identifier}_class";
-    my $original_local_name  = "original_$local_name";
-    my $original_reader      = "$pvt$original_local_name";
-    my $traitsfor_local_name = $local_name . '_traits';
-    my $traitsfor_reader     = "$pvt$traitsfor_local_name";
-
-    ### $full_name
-    has "$pvt$original_local_name" => (
-        traits     => [Shortcuts],
-        is         => 'lazy',
-        isa        => LoadableClass,
-        constraint => sub { $_->isa($full_name) },
-        coerce     => 1,
-        init_arg   => "$pvt$local_name",
-        builder    => sub { $full_name },
-    );
-
-    has "$pvt$local_name" => (
-        traits     => [Shortcuts],
-        is         => 'lazy',
-        isa        => LoadableClass,
-        constraint => sub { $_->isa($full_name) },
-        coerce     => 1,
-        init_arg   => undef,
-        builder    => sub {
-            my $self = shift @_;
-
-            return with_traits( $self->$original_reader() =>
-                $self->$traitsfor_reader()->flatten,
-            );
-        },
-    );
-
-    # XXX do the same original/local init_arg swizzle here too?
-    has "$pvt$traitsfor_local_name" => (
-        traits  => [Shortcuts, 'Array'],
-        is      => 'lazy',
-        isa     => ArrayRef[LoadableRole],
-        builder => sub { [ ] },
-        handles => {
-            "${pvt}has_$traitsfor_local_name" => 'count',
-        },
-    );
-
-    return;
-}
-
 !!42;
 
 __END__
@@ -212,15 +233,13 @@ __END__
 
 =for :stopwords Chris Weyl Kulag Parameterized Namespacing findable
 
-=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
-
 =head1 NAME
 
 MooseX::RelatedClasses - Parameterized role for related class attributes
 
 =head1 VERSION
 
-This document describes version 0.010 of MooseX::RelatedClasses - released April 10, 2015 as part of MooseX-RelatedClasses.
+This document describes version 0.011 of MooseX::RelatedClasses - released April 03, 2017 as part of MooseX-RelatedClasses.
 
 =head1 SYNOPSIS
 
@@ -233,7 +252,7 @@ This document describes version 0.010 of MooseX::RelatedClasses - released April
     use MooseX::RelatedClasses;
     related_class name => 'Thinger', namespace => undef;
 
-    # ...or this (preferred):
+    # ...or this:
     use MooseX::RelatedClasses;
     related_class 'Thinger', namespace => undef;
 
@@ -285,18 +304,6 @@ way to make that difficult-to-impossible without a significant effort?
 This package aims to end that, by providing an easy, flexible way of defining
 "related classes", their base class, and allowing traits to be specified.
 
-=head2 This is early code!
-
-This package is very new, and is still being vetted "in use", as it were.  The
-documentation (or tests) may not be 100%, but it's in active use.  Pull
-requests are happily received :)
-
-=head2 Documentation
-
-See the SYNOPSIS for information; the tests are also useful here as well.
-
-I _did_ warn you this is a very early release, right?
-
 =head1 ROLE PARAMETERS
 
 Parameterized roles accept parameters that influence their construction.  This role accepts the following parameters.
@@ -479,15 +486,10 @@ And more like:
 Anonymous classes are only ever composed if traits for a related class are
 supplied.
 
-=head1 SOURCE
-
-The development version is on github at L<http://https://github.com/RsrchBoy/moosex-relatedclasses>
-and may be cloned from L<git://https://github.com/RsrchBoy/moosex-relatedclasses.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/moosex-relatedclasses/issues
+L<https://github.com/RsrchBoy/moosex-relatedclasses/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -497,25 +499,6 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head2 I'm a material boy in a material world
-
-=begin html
-
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
-<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
-<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-relatedclasses&title=RsrchBoy's%20CPAN%20MooseX-RelatedClasses&tags=%22RsrchBoy's%20MooseX-RelatedClasses%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
-
-=end html
-
-Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
-rather B<it is simply a very pleasant surprise>. I largely create and release
-works like this because I need them or I find it enjoyable; however, don't let
-that stop you if you feel like it ;)
-
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-relatedclasses&title=RsrchBoy's%20CPAN%20MooseX-RelatedClasses&tags=%22RsrchBoy's%20MooseX-RelatedClasses%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
-
 =head1 CONTRIBUTOR
 
 =for stopwords Kulag
